/****************************************************************************
** Meta object code from reading C++ file 'etesyncresource.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdepim-runtime-26.04.2/resources/etesync/etesyncresource.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QSet>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'etesyncresource.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15EteSyncResourceE_t {};
} // unnamed namespace

template <> constexpr inline auto EteSyncResource::qt_create_metaobjectdata<qt_meta_tag_ZN15EteSyncResourceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EteSyncResource",
        "retrieveCollections",
        "",
        "retrieveItems",
        "Akonadi::Collection",
        "col",
        "itemAdded",
        "Akonadi::Item",
        "item",
        "collection",
        "itemChanged",
        "QSet<QByteArray>",
        "parts",
        "itemRemoved",
        "collectionAdded",
        "parent",
        "collectionChanged",
        "changedAttributes",
        "collectionRemoved",
        "onReloadConfiguration",
        "initialiseDone",
        "successful",
        "error",
        "slotItemsRetrieved",
        "KJob*",
        "job",
        "slotCollectionsRetrieved",
        "slotTokenRefreshed",
        "showErrorDialog",
        "errorText",
        "errorDetails",
        "title"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'retrieveCollections'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'retrieveItems'
        QtMocHelpers::SlotData<void(const Akonadi::Collection &)>(3, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'itemAdded'
        QtMocHelpers::SlotData<void(const Akonadi::Item &, const Akonadi::Collection &)>(6, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 4, 9 },
        }}),
        // Slot 'itemChanged'
        QtMocHelpers::SlotData<void(const Akonadi::Item &, const QSet<QByteArray> &)>(10, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 11, 12 },
        }}),
        // Slot 'itemRemoved'
        QtMocHelpers::SlotData<void(const Akonadi::Item &)>(13, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'collectionAdded'
        QtMocHelpers::SlotData<void(const Akonadi::Collection &, const Akonadi::Collection &)>(14, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 4, 9 }, { 0x80000000 | 4, 15 },
        }}),
        // Slot 'collectionChanged'
        QtMocHelpers::SlotData<void(const Akonadi::Collection &, const QSet<QByteArray> &)>(16, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 4, 9 }, { 0x80000000 | 11, 17 },
        }}),
        // Slot 'collectionRemoved'
        QtMocHelpers::SlotData<void(const Akonadi::Collection &)>(18, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 4, 9 },
        }}),
        // Slot 'onReloadConfiguration'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'initialiseDone'
        QtMocHelpers::SlotData<void(bool, const QString &)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 21 }, { QMetaType::QString, 22 },
        }}),
        // Slot 'slotItemsRetrieved'
        QtMocHelpers::SlotData<void(KJob *)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Slot 'slotCollectionsRetrieved'
        QtMocHelpers::SlotData<void(KJob *)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Slot 'slotTokenRefreshed'
        QtMocHelpers::SlotData<void(bool)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 21 },
        }}),
        // Slot 'showErrorDialog'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 29 }, { QMetaType::QString, 30 }, { QMetaType::QString, 31 },
        }}),
        // Slot 'showErrorDialog'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(28, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 29 }, { QMetaType::QString, 30 },
        }}),
        // Slot 'showErrorDialog'
        QtMocHelpers::SlotData<void(const QString &)>(28, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 29 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<EteSyncResource, qt_meta_tag_ZN15EteSyncResourceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject EteSyncResource::staticMetaObject = { {
    QMetaObject::SuperData::link<Akonadi::ResourceBase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15EteSyncResourceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15EteSyncResourceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15EteSyncResourceE_t>.metaTypes,
    nullptr
} };

void EteSyncResource::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EteSyncResource *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->retrieveCollections(); break;
        case 1: _t->retrieveItems((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1]))); break;
        case 2: _t->itemAdded((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2]))); break;
        case 3: _t->itemChanged((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSet<QByteArray>>>(_a[2]))); break;
        case 4: _t->itemRemoved((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 5: _t->collectionAdded((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2]))); break;
        case 6: _t->collectionChanged((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSet<QByteArray>>>(_a[2]))); break;
        case 7: _t->collectionRemoved((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1]))); break;
        case 8: _t->onReloadConfiguration(); break;
        case 9: _t->initialiseDone((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 10: _t->slotItemsRetrieved((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 11: _t->slotCollectionsRetrieved((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 12: _t->slotTokenRefreshed((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->showErrorDialog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 14: _t->showErrorDialog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 15: _t->showErrorDialog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSet<QByteArray> >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSet<QByteArray> >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *EteSyncResource::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EteSyncResource::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15EteSyncResourceE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Akonadi::AgentBase::ObserverV2"))
        return static_cast< Akonadi::AgentBase::ObserverV2*>(this);
    return Akonadi::ResourceBase::qt_metacast(_clname);
}

int EteSyncResource::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Akonadi::ResourceBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    return _id;
}
QT_WARNING_POP
