/****************************************************************************
** Meta object code from reading C++ file 'settingsadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "settingsadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'settingsadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15SettingsAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto SettingsAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN15SettingsAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SettingsAdaptor",
        "D-Bus Interface",
        "org.kde.Akonadi.OpenXchange.Settings",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.Akonadi.OpenXchange.Settings\">\n    <"
        "method name=\"save\"/>\n    <method name=\"baseUrl\">\n      <arg "
        "direction=\"out\" type=\"s\"/>\n    </method>\n    <method name=\""
        "setBaseUrl\">\n      <arg direction=\"in\" type=\"s\"/>\n    </met"
        "hod>\n    <method name=\"username\">\n      <arg direction=\"out\""
        " type=\"s\"/>\n    </method>\n    <method name=\"setUsername\">\n "
        "     <arg direction=\"in\" type=\"s\"/>\n    </method>\n    <metho"
        "d name=\"password\">\n      <arg direction=\"out\" type=\"s\"/>\n "
        "   </method>\n    <method name=\"setPassword\">\n      <arg direct"
        "ion=\"in\" type=\"s\"/>\n    </method>\n    <method name=\"useIncr"
        "ementalUpdates\">\n      <arg direction=\"out\" type=\"b\"/>\n    "
        "</method>\n    <method name=\"setUseIncrementalUpdates\">\n      <"
        "arg direction=\"in\" type=\"b\"/>\n    </method>\n    <method name"
        "=\"foldersLastSync\">\n      <arg direction=\"out\" type=\"t\"/>\n"
        "    </method>\n    <method name=\"setFoldersLastSync\">\n      <ar"
        "g direction=\"in\" type=\"t\"/>\n    </method>\n    <method name=\""
        "objectsLastSync\">\n      <arg direction=\"out\" type=\"s\"/>\n   "
        " </method>\n    <method name=\"setObjectsLastSync\">\n      <arg d"
        "irection=\"in\" type=\"s\"/>\n    </method>\n  </interface>\n",
        "baseUrl",
        "",
        "foldersLastSync",
        "objectsLastSync",
        "password",
        "save",
        "setBaseUrl",
        "in0",
        "setFoldersLastSync",
        "setObjectsLastSync",
        "setPassword",
        "setUseIncrementalUpdates",
        "setUsername",
        "useIncrementalUpdates",
        "username"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'baseUrl'
        QtMocHelpers::SlotData<QString()>(5, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'foldersLastSync'
        QtMocHelpers::SlotData<qulonglong()>(7, 6, QMC::AccessPublic, QMetaType::ULongLong),
        // Slot 'objectsLastSync'
        QtMocHelpers::SlotData<QString()>(8, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'password'
        QtMocHelpers::SlotData<QString()>(9, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'save'
        QtMocHelpers::SlotData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setBaseUrl'
        QtMocHelpers::SlotData<void(const QString &)>(11, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'setFoldersLastSync'
        QtMocHelpers::SlotData<void(qulonglong)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 12 },
        }}),
        // Slot 'setObjectsLastSync'
        QtMocHelpers::SlotData<void(const QString &)>(14, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'setPassword'
        QtMocHelpers::SlotData<void(const QString &)>(15, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'setUseIncrementalUpdates'
        QtMocHelpers::SlotData<void(bool)>(16, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 12 },
        }}),
        // Slot 'setUsername'
        QtMocHelpers::SlotData<void(const QString &)>(17, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'useIncrementalUpdates'
        QtMocHelpers::SlotData<bool()>(18, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'username'
        QtMocHelpers::SlotData<QString()>(19, 6, QMC::AccessPublic, QMetaType::QString),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<SettingsAdaptor, qt_meta_tag_ZN15SettingsAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject SettingsAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SettingsAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SettingsAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15SettingsAdaptorE_t>.metaTypes,
    nullptr
} };

void SettingsAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SettingsAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->baseUrl();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 1: { qulonglong _r = _t->foldersLastSync();
            if (_a[0]) *reinterpret_cast<qulonglong*>(_a[0]) = std::move(_r); }  break;
        case 2: { QString _r = _t->objectsLastSync();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 3: { QString _r = _t->password();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->save(); break;
        case 5: _t->setBaseUrl((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->setFoldersLastSync((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 7: _t->setObjectsLastSync((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->setPassword((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->setUseIncrementalUpdates((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->setUsername((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: { bool _r = _t->useIncrementalUpdates();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: { QString _r = _t->username();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *SettingsAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SettingsAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SettingsAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int SettingsAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    return _id;
}
QT_WARNING_POP
