/****************************************************************************
** Meta object code from reading C++ file 'settingsadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "settingsadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'settingsadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15SettingsAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto SettingsAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN15SettingsAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SettingsAdaptor",
        "D-Bus Interface",
        "org.kde.Akonadi.davGroupware.Settings",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.Akonadi.davGroupware.Settings\">\n    "
        "<method name=\"save\"/>\n    <method name=\"settingsVersion\">\n  "
        "    <arg direction=\"out\" type=\"i\"/>\n    </method>\n    <metho"
        "d name=\"setSettingsVersion\">\n      <arg direction=\"in\" type=\""
        "i\"/>\n    </method>\n    <method name=\"displayName\">\n      <ar"
        "g direction=\"out\" type=\"s\"/>\n    </method>\n    <method name="
        "\"setDisplayName\">\n      <arg direction=\"in\" type=\"s\"/>\n   "
        " </method>\n    <method name=\"refreshInterval\">\n      <arg dire"
        "ction=\"out\" type=\"i\"/>\n    </method>\n    <method name=\"setR"
        "efreshInterval\">\n      <arg direction=\"in\" type=\"i\"/>\n    <"
        "/method>\n    <method name=\"remoteUrls\">\n      <arg direction=\""
        "out\" type=\"as\"/>\n    </method>\n    <method name=\"setRemoteUr"
        "ls\">\n      <arg direction=\"in\" type=\"as\"/>\n    </method>\n "
        "   <method name=\"defaultUsername\">\n      <arg direction=\"out\""
        " type=\"s\"/>\n    </method>\n    <method name=\"setDefaultUsernam"
        "e\">\n      <arg direction=\"in\" type=\"s\"/>\n    </method>\n   "
        " <method name=\"limitSyncRange\">\n      <arg direction=\"out\" ty"
        "pe=\"b\"/>\n    </method>\n    <method name=\"setLimitSyncRange\">"
        "\n      <arg direction=\"in\" type=\"b\"/>\n    </method>\n    <me"
        "thod name=\"syncRangeStartNumber\">\n      <arg direction=\"out\" "
        "type=\"s\"/>\n    </method>\n    <method name=\"setSyncRangeStartN"
        "umber\">\n      <arg direction=\"in\" type=\"s\"/>\n    </method>\n"
        "    <method name=\"syncRangeStartType\">\n      <arg direction=\"o"
        "ut\" type=\"s\"/>\n    </method>\n    <method name=\"setSyncRangeS"
        "tartType\">\n      <arg direction=\"in\" type=\"s\"/>\n    </metho"
        "d>\n    <method name=\"collectionsUrlsMappings\">\n      <arg dire"
        "ction=\"out\" type=\"s\"/>\n    </method>\n    <method name=\"setC"
        "ollectionsUrlsMappings\">\n      <arg direction=\"in\" type=\"s\"/"
        ">\n    </method>\n    <method name=\"readOnly\">\n      <arg direc"
        "tion=\"out\" type=\"b\"/>\n    </method>\n    <method name=\"setRe"
        "adOnly\">\n      <arg direction=\"in\" type=\"b\"/>\n    </method>"
        "\n  </interface>\n",
        "collectionsUrlsMappings",
        "",
        "defaultUsername",
        "displayName",
        "limitSyncRange",
        "readOnly",
        "refreshInterval",
        "remoteUrls",
        "save",
        "setCollectionsUrlsMappings",
        "in0",
        "setDefaultUsername",
        "setDisplayName",
        "setLimitSyncRange",
        "setReadOnly",
        "setRefreshInterval",
        "setRemoteUrls",
        "setSettingsVersion",
        "setSyncRangeStartNumber",
        "setSyncRangeStartType",
        "settingsVersion",
        "syncRangeStartNumber",
        "syncRangeStartType"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'collectionsUrlsMappings'
        QtMocHelpers::SlotData<QString()>(5, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'defaultUsername'
        QtMocHelpers::SlotData<QString()>(7, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'displayName'
        QtMocHelpers::SlotData<QString()>(8, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'limitSyncRange'
        QtMocHelpers::SlotData<bool()>(9, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'readOnly'
        QtMocHelpers::SlotData<bool()>(10, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'refreshInterval'
        QtMocHelpers::SlotData<int()>(11, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'remoteUrls'
        QtMocHelpers::SlotData<QStringList()>(12, 6, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'save'
        QtMocHelpers::SlotData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setCollectionsUrlsMappings'
        QtMocHelpers::SlotData<void(const QString &)>(14, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'setDefaultUsername'
        QtMocHelpers::SlotData<void(const QString &)>(16, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'setDisplayName'
        QtMocHelpers::SlotData<void(const QString &)>(17, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'setLimitSyncRange'
        QtMocHelpers::SlotData<void(bool)>(18, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Slot 'setReadOnly'
        QtMocHelpers::SlotData<void(bool)>(19, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Slot 'setRefreshInterval'
        QtMocHelpers::SlotData<void(int)>(20, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Slot 'setRemoteUrls'
        QtMocHelpers::SlotData<void(const QStringList &)>(21, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 15 },
        }}),
        // Slot 'setSettingsVersion'
        QtMocHelpers::SlotData<void(int)>(22, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Slot 'setSyncRangeStartNumber'
        QtMocHelpers::SlotData<void(const QString &)>(23, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'setSyncRangeStartType'
        QtMocHelpers::SlotData<void(const QString &)>(24, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'settingsVersion'
        QtMocHelpers::SlotData<int()>(25, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'syncRangeStartNumber'
        QtMocHelpers::SlotData<QString()>(26, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'syncRangeStartType'
        QtMocHelpers::SlotData<QString()>(27, 6, QMC::AccessPublic, QMetaType::QString),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<SettingsAdaptor, qt_meta_tag_ZN15SettingsAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject SettingsAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SettingsAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SettingsAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15SettingsAdaptorE_t>.metaTypes,
    nullptr
} };

void SettingsAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SettingsAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->collectionsUrlsMappings();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 1: { QString _r = _t->defaultUsername();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 2: { QString _r = _t->displayName();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 3: { bool _r = _t->limitSyncRange();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: { bool _r = _t->readOnly();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: { int _r = _t->refreshInterval();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 6: { QStringList _r = _t->remoteUrls();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->save(); break;
        case 8: _t->setCollectionsUrlsMappings((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->setDefaultUsername((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->setDisplayName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->setLimitSyncRange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->setReadOnly((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->setRefreshInterval((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->setRemoteUrls((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 15: _t->setSettingsVersion((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->setSyncRangeStartNumber((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->setSyncRangeStartType((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 18: { int _r = _t->settingsVersion();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 19: { QString _r = _t->syncRangeStartNumber();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 20: { QString _r = _t->syncRangeStartType();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *SettingsAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SettingsAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SettingsAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int SettingsAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 21;
    }
    return _id;
}
QT_WARNING_POP
